==> msc-generator_8.4.1.orig.tar.xz: msc-generator-8.4.1/src/libflow/flow_parser_csh.h <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_FLOW_CSH_FLOW_PARSER_CSH_H_INCLUDED
# define YY_FLOW_CSH_FLOW_PARSER_CSH_H_INCLUDED
/* Debug traces.  */
#ifndef FLOW_CSH_DEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define FLOW_CSH_DEBUG 1
#  else
#   define FLOW_CSH_DEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define FLOW_CSH_DEBUG 0
# endif /* ! defined YYDEBUG */
#endif  /* ! defined FLOW_CSH_DEBUG */
#if FLOW_CSH_DEBUG
extern int flow_csh_debug;
#endif
/* "%code requires" blocks.  */
#line 4 "../../../msc-generator/src/libflow/flow_lang.yy"
 #define C_S_H_IS_COMPILED 
#line 34 "../../../msc-generator/src/libflow/flow_lang.yy"

    #include "cgen_shapes.h"
    #include "flowcsh.h"
    #include "flowchart.h"
    #include "flow_lexer.h"

    //To allow including both flow_parse_{compile,csh}.h
    #undef C_S_H
    #undef CHAR_IF_CSH

    #ifdef C_S_H_IS_COMPILED
        #define C_S_H true
        #define CHAR_IF_CSH(A) char

    #else
        #define C_S_H false
        #define CHAR_IF_CSH(A) A
    #endif

    using namespace flow;

#line 81 "flow_parser_csh.h"

/* Token kinds.  */
#ifndef FLOW_CSH_TOKENTYPE
# define FLOW_CSH_TOKENTYPE
  enum flow_csh_tokentype
  {
    FLOW_CSH_EMPTY = -2,
    TOK_EOF = 0,                   /* TOK_EOF  */
    FLOW_CSH_error = 256,          /* error  */
    FLOW_CSH_UNDEF = 257,          /* "invalid token"  */
    TOK_STRING = 258,              /* TOK_STRING  */
    TOK_QSTRING = 259,             /* TOK_QSTRING  */
    TOK_NUMBER = 260,              /* TOK_NUMBER  */
    TOK_DASH = 261,                /* TOK_DASH  */
    TOK_EQUAL = 262,               /* TOK_EQUAL  */
    TOK_COMMA = 263,               /* TOK_COMMA  */
    TOK_SEMICOLON = 264,           /* TOK_SEMICOLON  */
    TOK_PLUS_PLUS = 265,           /* TOK_PLUS_PLUS  */
    TOK_OCBRACKET = 266,           /* TOK_OCBRACKET  */
    TOK_CCBRACKET = 267,           /* TOK_CCBRACKET  */
    TOK_OSBRACKET = 268,           /* TOK_OSBRACKET  */
    TOK_CSBRACKET = 269,           /* TOK_CSBRACKET  */
    TOK_IF = 270,                  /* TOK_IF  */
    TOK_STEP = 271,                /* TOK_STEP  */
    TOK_REPEAT = 272,              /* TOK_REPEAT  */
    TOK_START = 273,               /* TOK_START  */
    TOK_STOP = 274,                /* TOK_STOP  */
    TOK_GOTO = 275,                /* TOK_GOTO  */
    TOK_BRANCH = 276,              /* TOK_BRANCH  */
    TOK_THEN = 277,                /* TOK_THEN  */
    TOK_ELSE = 278,                /* TOK_ELSE  */
    TOK_YES = 279,                 /* TOK_YES  */
    TOK_NO = 280,                  /* TOK_NO  */
    TOK_SHAPE_COMMAND = 281,       /* TOK_SHAPE_COMMAND  */
    TOK_BYE = 282,                 /* TOK_BYE  */
    TOK_COLON_STRING = 283,        /* TOK_COLON_STRING  */
    TOK_COLON_QUOTED_STRING = 284, /* TOK_COLON_QUOTED_STRING  */
    TOK_COLORDEF = 285,            /* TOK_COLORDEF  */
    TOK_COMMAND_DEFSHAPE = 286,    /* TOK_COMMAND_DEFSHAPE  */
    TOK_COMMAND_DEFCOLOR = 287,    /* TOK_COMMAND_DEFCOLOR  */
    TOK_COMMAND_DEFSTYLE = 288,    /* TOK_COMMAND_DEFSTYLE  */
    TOK_COMMAND_DEFDESIGN = 289,   /* TOK_COMMAND_DEFDESIGN  */
    TOK__NEVER__HAPPENS = 290,     /* TOK__NEVER__HAPPENS  */
    TOK__NEVER__HAPPENS2 = 291,    /* TOK__NEVER__HAPPENS2  */
    TOK_UNRECOGNIZED_CHAR = 292,   /* TOK_UNRECOGNIZED_CHAR  */
    TOK_WHITESPACE = 293,          /* TOK_WHITESPACE  */
    TOK_NEWLINE = 294,             /* TOK_NEWLINE  */
    TOK_COMMENT = 295              /* TOK_COMMENT  */
  };
  typedef enum flow_csh_tokentype flow_csh_token_kind_t;
#endif

/* Value type.  */
#if ! defined FLOW_CSH_STYPE && ! defined FLOW_CSH_STYPE_IS_DECLARED
union FLOW_CSH_STYPE
{
#line 92 "../../../msc-generator/src/libflow/flow_lang.yy"

    str_view                                str;
    multi_segment_string                    multi_str;
    gsl::owner<std::vector<std::string>*>   stringlist;
    ShapeElement::Type                      shapecommand;
    CHAR_IF_CSH(Step::KeywordHelper)        steptype;
    gsl::owner<CHAR_IF_CSH(Shape)*>         shape;
    gsl::owner<CHAR_IF_CSH(ShapeElement)*>  shapeelement;
    gsl::owner<CHAR_IF_CSH(Attribute)*>     attribute;
    gsl::owner<CHAR_IF_CSH(AttributeList)*> attributelist;
    gsl::owner<CHAR_IF_CSH(FlowElement)*>   instruction;
    gsl::owner<CHAR_IF_CSH(FElementList)*>  instruction_list;
    gsl::owner<CHAR_IF_CSH(Branch)*>        branch;

#line 153 "flow_parser_csh.h"

};
typedef union FLOW_CSH_STYPE FLOW_CSH_STYPE;
# define FLOW_CSH_STYPE_IS_TRIVIAL 1
# define FLOW_CSH_STYPE_IS_DECLARED 1
#endif

/* Location type.  */
typedef SourceLocationRange<C_S_H> FLOW_CSH_LTYPE;




int flow_csh_parse (flow::FlowCsh &csh, sv_reader<C_S_H> &input);


#endif /* !YY_FLOW_CSH_FLOW_PARSER_CSH_H_INCLUDED  */

==> msc-generator_8.6.4.orig.tar.xz: msc-generator-8.6.4/src/libflow/flow_parser_csh.h <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_FLOW_CSH_FLOW_PARSER_CSH_H_INCLUDED
# define YY_FLOW_CSH_FLOW_PARSER_CSH_H_INCLUDED
/* Debug traces.  */
#ifndef FLOW_CSH_DEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define FLOW_CSH_DEBUG 1
#  else
#   define FLOW_CSH_DEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define FLOW_CSH_DEBUG 0
# endif /* ! defined YYDEBUG */
#endif  /* ! defined FLOW_CSH_DEBUG */
#if FLOW_CSH_DEBUG
extern int flow_csh_debug;
#endif
/* "%code requires" blocks.  */
#line 4 "./flow_lang.yy"
 #define C_S_H_IS_COMPILED 
#line 34 "./flow_lang.yy"

    #include "cgen_shapes.h"
    #include "flowcsh.h"
    #include "flowchart.h"
    #include "flow_lexer.h"

    //To allow including both flow_parse_{compile,csh}.h
    #undef C_S_H
    #undef CHAR_IF_CSH

    #ifdef C_S_H_IS_COMPILED
        #define C_S_H true
        #define CHAR_IF_CSH(A) char

    #else
        #define C_S_H false
        #define CHAR_IF_CSH(A) A
    #endif

    using namespace flow;

#line 81 "flow_parser_csh.h"

/* Token kinds.  */
#ifndef FLOW_CSH_TOKENTYPE
# define FLOW_CSH_TOKENTYPE
  enum flow_csh_tokentype
  {
    FLOW_CSH_EMPTY = -2,
    TOK_EOF = 0,                   /* TOK_EOF  */
    FLOW_CSH_error = 256,          /* error  */
    FLOW_CSH_UNDEF = 257,          /* "invalid token"  */
    TOK_STRING = 258,              /* TOK_STRING  */
    TOK_QSTRING = 259,             /* TOK_QSTRING  */
    TOK_NUMBER = 260,              /* TOK_NUMBER  */
    TOK_DASH = 261,                /* TOK_DASH  */
    TOK_EQUAL = 262,               /* TOK_EQUAL  */
    TOK_COMMA = 263,               /* TOK_COMMA  */
    TOK_SEMICOLON = 264,           /* TOK_SEMICOLON  */
    TOK_PLUS_PLUS = 265,           /* TOK_PLUS_PLUS  */
    TOK_OCBRACKET = 266,           /* TOK_OCBRACKET  */
    TOK_CCBRACKET = 267,           /* TOK_CCBRACKET  */
    TOK_OSBRACKET = 268,           /* TOK_OSBRACKET  */
    TOK_CSBRACKET = 269,           /* TOK_CSBRACKET  */
    TOK_IF = 270,                  /* TOK_IF  */
    TOK_STEP = 271,                /* TOK_STEP  */
    TOK_REPEAT = 272,              /* TOK_REPEAT  */
    TOK_START = 273,               /* TOK_START  */
    TOK_STOP = 274,                /* TOK_STOP  */
    TOK_GOTO = 275,                /* TOK_GOTO  */
    TOK_BRANCH = 276,              /* TOK_BRANCH  */
    TOK_THEN = 277,                /* TOK_THEN  */
    TOK_ELSE = 278,                /* TOK_ELSE  */
    TOK_YES = 279,                 /* TOK_YES  */
    TOK_NO = 280,                  /* TOK_NO  */
    TOK_SHAPE_COMMAND = 281,       /* TOK_SHAPE_COMMAND  */
    TOK_BYE = 282,                 /* TOK_BYE  */
    TOK_COLON_STRING = 283,        /* TOK_COLON_STRING  */
    TOK_COLON_QUOTED_STRING = 284, /* TOK_COLON_QUOTED_STRING  */
    TOK_COLORDEF = 285,            /* TOK_COLORDEF  */
    TOK_COMMAND_DEFSHAPE = 286,    /* TOK_COMMAND_DEFSHAPE  */
    TOK_COMMAND_DEFCOLOR = 287,    /* TOK_COMMAND_DEFCOLOR  */
    TOK_COMMAND_DEFSTYLE = 288,    /* TOK_COMMAND_DEFSTYLE  */
    TOK_COMMAND_DEFDESIGN = 289,   /* TOK_COMMAND_DEFDESIGN  */
    TOK__NEVER__HAPPENS = 290,     /* TOK__NEVER__HAPPENS  */
    TOK__NEVER__HAPPENS2 = 291,    /* TOK__NEVER__HAPPENS2  */
    TOK_UNRECOGNIZED_CHAR = 292,   /* TOK_UNRECOGNIZED_CHAR  */
    TOK_WHITESPACE = 293,          /* TOK_WHITESPACE  */
    TOK_NEWLINE = 294,             /* TOK_NEWLINE  */
    TOK_COMMENT = 295              /* TOK_COMMENT  */
  };
  typedef enum flow_csh_tokentype flow_csh_token_kind_t;
#endif

/* Value type.  */
#if ! defined FLOW_CSH_STYPE && ! defined FLOW_CSH_STYPE_IS_DECLARED
union FLOW_CSH_STYPE
{
#line 92 "./flow_lang.yy"

    str_view                                str;
    multi_segment_string                    multi_str;
    gsl::owner<std::vector<std::string>*>   stringlist;
    ShapeElement::Type                      shapecommand;
    CHAR_IF_CSH(Step::KeywordHelper)        steptype;
    gsl::owner<CHAR_IF_CSH(Shape)*>         shape;
    gsl::owner<CHAR_IF_CSH(ShapeElement)*>  shapeelement;
    gsl::owner<CHAR_IF_CSH(Attribute)*>     attribute;
    gsl::owner<CHAR_IF_CSH(AttributeList)*> attributelist;
    gsl::owner<CHAR_IF_CSH(FlowElement)*>   instruction;
    gsl::owner<CHAR_IF_CSH(FElementList)*>  instruction_list;
    gsl::owner<CHAR_IF_CSH(Branch)*>        branch;

#line 153 "flow_parser_csh.h"

};
typedef union FLOW_CSH_STYPE FLOW_CSH_STYPE;
# define FLOW_CSH_STYPE_IS_TRIVIAL 1
# define FLOW_CSH_STYPE_IS_DECLARED 1
#endif

/* Location type.  */
typedef SourceLocationRange<C_S_H> FLOW_CSH_LTYPE;




int flow_csh_parse (flow::FlowCsh &csh, sv_reader<C_S_H> &input);


#endif /* !YY_FLOW_CSH_FLOW_PARSER_CSH_H_INCLUDED  */
